# emoji-numbers
Simple and silly Python package to print numbers using Emoji digits.

This project is used as part of the PyConUS tutorial **Publishing your Python project, the conda way** 
presented at [PyConUS](https://us.pycon.org/2023/schedule/presentation/94/) by:

* [Dave Clements](https://us.pycon.org/2023/speaker/profile/108/)
* [Bianca Henderson](https://us.pycon.org/2023/speaker/profile/75/)
* [Mahe Iram Khan](https://us.pycon.org/2023/speaker/profile/166/)
* [Valerio Maggio](https://us.pycon.org/2023/speaker/profile/109/)

This package will be published on PyPi and it will be used solely
to demonstrate how to add `pip` dependecies to a `conda` package.
